@@ -1,30 +1,55 @@
 var index =
 [
     [ "Contributor's Guide", "index.html#contrib", null ],
-    [ "Building Kea with Unit tests", "index.html#buildingKeaWithUnitTests", null ],
-    [ "Performance", "index.html#performance", null ],
+    [ "Quality Assurance", "index.html#qa", null ],
     [ "Hooks Framework", "index.html#hooksFramework", null ],
     [ "DHCP Maintenance Guide", "index.html#dhcpMaintenanceGuide", null ],
     [ "Kea libraries", "index.html#libraries", null ],
+    [ "Kea hook libraries", "index.html#hooks", null ],
     [ "Miscellaneous Topics", "index.html#miscellaneousTopics", null ],
     [ "Kea Contributor's Guide", "d7/df4/contributorGuide.html", null ],
+    [ "Quality Assurance in Kea", "d6/d4f/qaIntro.html", [
+      [ "Running CI pipeline on Github", "d6/d4f/qaIntro.html#ciGithub", null ],
+      [ "Running CI pipeline on Gitlab", "d6/d4f/qaIntro.html#ciGitlab", null ],
+      [ "Running CI pipeline on Jenkins", "d6/d4f/qaIntro.html#ciJenkins", null ],
+      [ "Running Cppcheck locally", "d6/d4f/qaIntro.html#ciCppcheck", null ],
+      [ "Running Valgrind locally", "d6/d4f/qaIntro.html#ciValgrind", null ]
+    ] ],
     [ "Building Kea with Unit Tests", "d1/d2e/unitTests.html", [
       [ "Environment Variables", "d1/d2e/unitTests.html#unitTestsEnvironmentVariables", null ],
       [ "Use Sanitizers", "d1/d2e/unitTests.html#unitTestsSanitizers", null ],
       [ "Databases Configuration for Unit Tests", "d1/d2e/unitTests.html#unitTestsDatabaseConfig", [
         [ "Database Users Required for Unit Tests", "d1/d2e/unitTests.html#unitTestsDatabaseUsers", null ],
         [ "MySQL Database", "d1/d2e/unitTests.html#mysqlUnitTestsPrerequisites", null ],
+        [ "MySQL Database with SSL/TLS", "d1/d2e/unitTests.html#mysqlUnitTestsTLS", null ],
         [ "PostgreSQL Database", "d1/d2e/unitTests.html#pgsqlUnitTestsPrerequisites", null ],
-        [ "Cassandra database", "d1/d2e/unitTests.html#cqlUnitTestsPrerequisites", null ]
+        [ "PostgreSQL Database with SSL/TLS", "d1/d2e/unitTests.html#pgsqlUnitTestsTLS", null ]
       ] ],
       [ "Kerberos Configuration for Unit Tests", "d1/d2e/unitTests.html#unitTestsKerberos", null ],
-      [ "Writing shell scripts and tests", "d1/d2e/unitTests.html#writingShellScriptsAndTests", null ]
+      [ "Running Unit Tests with Root Privileges", "d1/d2e/unitTests.html#unitTestsRootPrivileges", null ],
+      [ "Writing shell scripts and tests", "d1/d2e/unitTests.html#writingShellScriptsAndTests", null ],
+      [ "Regenerating configuration unit tests", "d1/d2e/unitTests.html#regeneratingConfigUnitTests", null ]
     ] ],
-    [ "Benchmarks: Measuring performance", "d8/de4/benchmarks.html", [
-      [ "benchmarksOverview", "d8/de4/benchmarks.html#benchmarksOverview", null ],
-      [ "Internal code organization", "d8/de4/benchmarks.html#benchmarksCode", null ],
-      [ "Explaining control flow in benchmarks", "d8/de4/benchmarks.html#benchmarkControlFlow", null ],
-      [ "Adding new benchmarks", "d8/de4/benchmarks.html#benchmarkNew", null ]
+    [ "Performance Testing", "dc/d3c/performance.html", "dc/d3c/performance" ],
+    [ "Fuzzing Kea", "d9/d8b/fuzzer.html", [
+      [ "Introduction", "d9/d8b/fuzzer.html#fuzzIntro", null ],
+      [ "Using the LLVMFuzzerTestOneInput Harness Function", "d9/d8b/fuzzer.html#LLVMFuzzerTestOneInput", [
+        [ "How to Build the LLVM Fuzzer", "d9/d8b/fuzzer.html#HowToBuild", null ],
+        [ "How to Run the LLVM Fuzzer", "d9/d8b/fuzzer.html#HowToRun", null ],
+        [ "The Code Structure of the LLVM Fuzzer", "d9/d8b/fuzzer.html#FuzzingStructure", null ],
+        [ "Development Considerations About LLVM Fuzzing in Kea", "d9/d8b/fuzzer.html#FuzzingConsiderations", null ]
+      ] ],
+      [ "Using AFL", "d9/d8b/fuzzer.html#usingAFL", [
+        [ "Fuzzing with Network Packets", "d9/d8b/fuzzer.html#fuzzTypeNetwork", null ],
+        [ "Fuzzing with Configuration Files", "d9/d8b/fuzzer.html#fuzzTypeConfig", null ],
+        [ "Building Kea for Fuzzing", "d9/d8b/fuzzer.html#fuzzBuild", null ],
+        [ "Fuzzing with Network Packets", "d9/d8b/fuzzer.html#fuzzRunNetwork", null ],
+        [ "Fuzzing with Configuration Files", "d9/d8b/fuzzer.html#fuzzRunConfig", null ],
+        [ "Fuzzing with Network Packets", "d9/d8b/fuzzer.html#fuzzInternalNetwork", null ],
+        [ "Fuzzing with Configuration Files", "d9/d8b/fuzzer.html#fuzzInternalConfig", null ],
+        [ "Changes Required for Multi-Threaded Kea", "d9/d8b/fuzzer.html#fuzzThreads", null ],
+        [ "Unit Test Failures", "d9/d8b/fuzzer.html#fuzzNotesUnitTests", null ]
+      ] ]
     ] ],
     [ "Hooks Developer's Guide", "df/d46/hooksdgDevelopersGuide.html", [
       [ "Introduction", "df/d46/hooksdgDevelopersGuide.html#hooksdgIntroduction", [
@@ -78,7 +103,10 @@ var index =
         [ "lease4_renew", "de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseRenew", null ],
         [ "lease4_release", "de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseRelease", null ],
         [ "lease4_decline", "de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseDecline", null ],
+        [ "ddns4_update", "de/df3/dhcpv4Hooks.html#dhcpv4HooksDdns4Update", null ],
         [ "leases4_committed", "de/df3/dhcpv4Hooks.html#dhcpv4Leases4Committed", null ],
+        [ "lease4_offer", "de/df3/dhcpv4Hooks.html#dhcpv4Lease4Offer", null ],
+        [ "lease4_server_decline", "de/df3/dhcpv4Hooks.html#dhcpv4Lease4ServerDecline", null ],
         [ "pkt4_send", "de/df3/dhcpv4Hooks.html#dhcpv4HooksPkt4Send", null ],
         [ "buffer4_send", "de/df3/dhcpv4Hooks.html#dhcpv4HooksBuffer4Send", null ],
         [ "lease4_expire", "de/df3/dhcpv4Hooks.html#dhcpv4HooksLease4Expire", null ],
@@ -101,6 +129,8 @@ var index =
         [ "lease6_rebind", "d1/d02/dhcpv6Hooks.html#dhcpv6HooksLease6Rebind", null ],
         [ "lease6_decline", "d1/d02/dhcpv6Hooks.html#dhcpv6HooksLease6Decline", null ],
         [ "lease6_release", "d1/d02/dhcpv6Hooks.html#dhcpv6HooksLease6Release", null ],
+        [ "ddns6_update", "d1/d02/dhcpv6Hooks.html#dhcpv6HooksDdns6Update", null ],
+        [ "addr6_register", "d1/d02/dhcpv6Hooks.html#dhcpv6HookAddr6Register", null ],
         [ "leases6_committed", "d1/d02/dhcpv6Hooks.html#dhcpv6Leases6Committed", null ],
         [ "pkt6_send", "d1/d02/dhcpv6Hooks.html#dhcpv6HooksPkt6Send", null ],
         [ "buffer6_send", "d1/d02/dhcpv6Hooks.html#dhcpv6HooksBuffer6Send", null ],
@@ -113,9 +143,10 @@ var index =
     [ "The Hooks API for the Control Agent", "d4/d6b/agentHooks.html", [
       [ "Introduction", "d4/d6b/agentHooks.html#agentHooksIntroduction", null ],
       [ "Hooks in the Control Agent", "d4/d6b/agentHooks.html#agentHooksHookPoints", [
-        [ "auth", "d4/d6b/agentHooks.html#agentHooksAuth", null ],
-        [ "response", "d4/d6b/agentHooks.html#agentHooksResponse", null ]
-      ] ]
+        [ "http_auth", "d4/d6b/agentHooks.html#agentHooksAuth", null ],
+        [ "http_response", "d4/d6b/agentHooks.html#agentHooksResponse", null ]
+      ] ],
+      [ "Handle and hook unload", "d4/d6b/agentHooks.html#agentHooksHandle", null ]
     ] ],
     [ "The Hooks API for the Kea DHCP DDNS (D2)", "d4/d7d/d2Hooks.html", [
       [ "Introduction", "d4/d7d/d2Hooks.html#d2HooksIntroduction", null ],
@@ -169,53 +200,6 @@ var index =
         [ "Hooks and Statically-Linked Kea", "d6/d6e/hooksmgMaintenanceGuide.html#hooksmgStaticLinking", null ]
       ] ]
     ] ],
-    [ "Kea High Availability Hooks Library", "d3/d96/libdhcp_ha.html", [
-      [ "Overview", "d3/d96/libdhcp_ha.html#haOverview", null ],
-      [ "Why Hook Library?", "d3/d96/libdhcp_ha.html#haWhyHookLibrary", null ],
-      [ "Notable Differences to ISC DHCP", "d3/d96/libdhcp_ha.html#haNotableDifferences", null ],
-      [ "Asynchronous Communication with Boost Asio", "d3/d96/libdhcp_ha.html#haAyncCommunication", null ],
-      [ "Client Classification in Load Balancing", "d3/d96/libdhcp_ha.html#haClientClassification", null ],
-      [ "HA Hooks Library Code Structure", "d3/d96/libdhcp_ha.html#haCodeStructure", [
-        [ "HA Service Class", "d3/d96/libdhcp_ha.html#haService", null ],
-        [ "HA Implementation Class", "d3/d96/libdhcp_ha.html#haImplementation", null ],
-        [ "Query Filter Class", "d3/d96/libdhcp_ha.html#haQueryFilter", null ],
-        [ "Communication State Class", "d3/d96/libdhcp_ha.html#haCommunicationState", null ],
-        [ "Command Creator Class", "d3/d96/libdhcp_ha.html#haCommandCreator", null ]
-      ] ],
-      [ "Future HA Hooks Library Improvement Ideas", "d3/d96/libdhcp_ha.html#haShortcomings", [
-        [ "Controlling State Machine", "d3/d96/libdhcp_ha.html#haStateMachineControl", null ],
-        [ "DNS Updates are not Coordinated", "d3/d96/libdhcp_ha.html#haNameUpdates", null ]
-      ] ],
-      [ "Multi-Threading Compatibility", "d3/d96/libdhcp_ha.html#haMTCompatibility", null ]
-    ] ],
-    [ "DHCP User Check Hooks Library", "d8/db2/libdhcp_user_chk.html", [
-      [ "user_chk: An Example Hooks Library", "d8/db2/libdhcp_user_chk.html#libdhcp_user_chkIntro", [
-        [ "Introduction", "d8/db2/libdhcp_user_chk.html#autotoc_md8", null ],
-        [ "User Registry Classes", "d8/db2/libdhcp_user_chk.html#autotoc_md9", null ],
-        [ "Callout Processing", "d8/db2/libdhcp_user_chk.html#autotoc_md10", null ],
-        [ "Using the library", "d8/db2/libdhcp_user_chk.html#autotoc_md11", [
-          [ "Creating the Registry File", "d8/db2/libdhcp_user_chk.html#autotoc_md12", null ],
-          [ "Configuring the DHCP Modules", "d8/db2/libdhcp_user_chk.html#autotoc_md13", null ]
-        ] ],
-        [ "User Check Outcome", "d8/db2/libdhcp_user_chk.html#autotoc_md14", null ]
-      ] ],
-      [ "Multi-Threading Compatibility", "d8/db2/libdhcp_user_chk.html#libdhcp_user_chkMTCompatibility", null ]
-    ] ],
-    [ "Kea Lease Commands Hooks Library", "d9/dda/libdhcp_lease_cmds.html", [
-      [ "Introduction", "d9/dda/libdhcp_lease_cmds.html#libdhcp_lease_cmdsIntro", null ],
-      [ "Lease Commands Overview", "d9/dda/libdhcp_lease_cmds.html#lease_cmds", null ],
-      [ "Lease Commands Code Overview", "d9/dda/libdhcp_lease_cmds.html#lease_cmdsCode", null ],
-      [ "Lease Commands Design choices", "d9/dda/libdhcp_lease_cmds.html#lease_cmdsDesigns", null ],
-      [ "Multi-Threading Compatibility", "d9/dda/libdhcp_lease_cmds.html#lease_cmdsMTCompatibility", null ]
-    ] ],
-    [ "Kea Stat Commands Hooks Library", "d1/d88/libdhcp_stat_cmds.html", [
-      [ "Introduction", "d1/d88/libdhcp_stat_cmds.html#libdhcp_stat_cmdsIntro", null ],
-      [ "Stat Commands Overview", "d1/d88/libdhcp_stat_cmds.html#stat_cmds", null ],
-      [ "Stat Commands Code Overview", "d1/d88/libdhcp_stat_cmds.html#stat_cmdsCode", [
-        [ "Lease Stat Commands Code Overview", "d1/d88/libdhcp_stat_cmds.html#stat_cmdsLeaseStatCode", null ]
-      ] ],
-      [ "Multi-Threading Compatibility", "d1/d88/libdhcp_stat_cmds.html#stat_cmdsMTCompatibility", null ]
-    ] ],
     [ "DHCPv4 Server Component", "d5/ded/dhcp4.html", "d5/ded/dhcp4" ],
     [ "DHCPv4-over-DHCPv6 DHCPv4 Server Side", "dc/db8/dhcpv4o6Dhcp4.html", [
       [ "DHCPv6-to-DHCPv4 Inter Process Communication", "dc/db8/dhcpv4o6Dhcp4.html#Dhcp4to6Ipc", null ],
@@ -262,17 +246,22 @@ var index =
     ] ],
     [ "Control Channel", "d2/d96/ctrlSocket.html", [
       [ "Control Channel Overview", "d2/d96/ctrlSocket.html#ctrlSocketOverview", null ],
-      [ "Using Control Channel", "d2/d96/ctrlSocket.html#ctrlSocketClient", null ],
+      [ "Using UNIX Control Channel", "d2/d96/ctrlSocket.html#ctrlSocketClient", null ],
       [ "Control Channel Implementation", "d2/d96/ctrlSocket.html#ctrlSocketImpl", null ],
+      [ "UNIX Control Channel Implementation", "d2/d96/ctrlSocket.html#unixCtrlSocketImpl", null ],
       [ "Accepting connections", "d2/d96/ctrlSocket.html#ctrlSocketConnections", null ],
       [ "Multi-Threading Consideration for Control Channel", "d2/d96/ctrlSocket.html#ctrlSocketMTConsiderations", null ]
     ] ],
     [ "DHCP Database Back-Ends", "d6/dbd/dhcpDatabaseBackends.html", [
       [ "Instantiation of Lease Managers", "d6/dbd/dhcpDatabaseBackends.html#dhcpdb-instantiation", [
         [ "MySQL connection string keywords", "d6/dbd/dhcpDatabaseBackends.html#dhcpdb-keywords-mysql", null ],
-        [ "PostgreSQL connection string keywords", "d6/dbd/dhcpDatabaseBackends.html#dhcpdb-keywords-pgsql", null ],
-        [ "Cassandra (CQL) connection string keywords", "d6/dbd/dhcpDatabaseBackends.html#dhcpdb-keywords-cql", null ],
-        [ "Infinite Valid Lifetime", "d6/dbd/dhcpDatabaseBackends.html#infinite-valid-lifetime", null ]
+        [ "PostgreSQL connection string keywords", "d6/dbd/dhcpDatabaseBackends.html#dhcpdb-keywords-pgsql", [
+          [ "Infinite Valid Lifetime", "d6/dbd/dhcpDatabaseBackends.html#infinite-valid-lifetime", null ]
+        ] ],
+        [ "Memfile Lease Back-End", "d6/dbd/dhcpDatabaseBackends.html#memfile-description", [
+          [ "DHCPv4 lease entry format in CSV files", "d6/dbd/dhcpDatabaseBackends.html#lease4-csv", null ]
+        ] ],
+        [ "DHCPv6 lease entry format in CSV files", "d6/dbd/dhcpDatabaseBackends.html#lease6-csv", null ]
       ] ],
       [ "Host Backends", "d6/dbd/dhcpDatabaseBackends.html#dhcpdb-host", [
         [ "Caching", "d6/dbd/dhcpDatabaseBackends.html#dhcpdb-caching", null ]
@@ -284,16 +273,6 @@ var index =
       [ "Alternate Configuration Backends", "d7/dc5/configBackend.html#configBackendHistoric", null ],
       [ "The JSON Configuration Backend", "d7/dc5/configBackend.html#configBackendJSONDesign", null ]
     ] ],
-    [ "perfdhcp Internals", "d6/de6/perfdhcpInternals.html", [
-      [ "perfdhcp Classes", "d6/de6/perfdhcpInternals.html#perfdhcpClasses", [
-        [ "CommandOptions (Command Options)", "d6/de6/perfdhcpInternals.html#perfdhcpCommandOptions", null ],
-        [ "TestControl (Test Control)", "d6/de6/perfdhcpInternals.html#perfdhcpTestControl", null ],
-        [ "StatsMgr (Statistics Manager)", "d6/de6/perfdhcpInternals.html#perfStatsMgr", null ],
-        [ "PerfPkt4 and PerfPkt6", "d6/de6/perfdhcpInternals.html#perfdhcpPkt", null ],
-        [ "LocalizedOption (Localized Option)", "d6/de6/perfdhcpInternals.html#perfdhcpLocalizedOption", null ],
-        [ "PktTransform (Packet Transform)", "d6/de6/perfdhcpInternals.html#perfdhcpPktTransform", null ]
-      ] ]
-    ] ],
     [ "libkea-util - Kea Utilities Library", "dd/dd6/libutil.html", [
       [ "Utilities", "dd/dd6/libutil.html#utilUtilities", null ],
       [ "Multi-Threading Consideration for Utilities", "dd/dd6/libutil.html#utilMTConsiderations", null ]
@@ -326,11 +305,18 @@ var index =
     [ "libkea-stats - Kea Statistics Library", "dd/d22/libstats.html", [
       [ "Multi-Threading Consideration for Statistics", "dd/d22/libstats.html#statsMTConsiderations", null ]
     ] ],
+    [ "libkea-asiodns - Kea I/O Library", "de/dd2/libasiodns.html", [
+      [ "Upstream Fetches", "de/dd2/libasiodns.html#autotoc_md55", [
+        [ "Sockets", "de/dd2/libasiodns.html#autotoc_md56", null ],
+        [ "Fetch Sequence", "de/dd2/libasiodns.html#autotoc_md57", null ]
+      ] ]
+    ] ],
     [ "libkea-dhcp_ddns - DHCP_DDNS Request I/O Library", "d2/d9a/libdhcp_ddns.html", [
       [ "Introduction", "d2/d9a/libdhcp_ddns.html#libdhcp_ddnsIntro", null ],
       [ "Multi-Threading Consideration for DHCP_DDNS Request I/O Library", "d2/d9a/libdhcp_ddns.html#libdhcp_ddnsMTConsiderations", null ]
     ] ],
     [ "libkea-dhcpsrv - Server DHCP Library", "d8/d5f/libdhcpsrv.html", [
+      [ "Global Parameters", "d8/d5f/libdhcpsrv.html#cfgglobals", null ],
       [ "Lease Manager", "d8/d5f/libdhcpsrv.html#leasemgr", null ],
       [ "Configuration Manager", "d8/d5f/libdhcpsrv.html#cfgmgr", null ],
       [ "Host Manager", "d8/d5f/libdhcpsrv.html#hostmgr", [
@@ -357,7 +343,7 @@ var index =
       [ "Introduction", "dd/d60/libeval.html#dhcpEvalIntroduction", null ],
       [ "Lexer generation using flex", "dd/d60/libeval.html#dhcpEvalLexer", null ],
       [ "Parser generation using bison", "dd/d60/libeval.html#dhcpEvalParser", null ],
-      [ "Generating parser files", "dd/d60/libeval.html#dhcpEvalMakefile", null ],
+      [ "Generating parser files", "dd/d60/libeval.html#dhcpEval", null ],
       [ "Configure options", "dd/d60/libeval.html#dhcpEvalConfigure", null ],
       [ "Supported tokens", "dd/d60/libeval.html#dhcpEvalToken", null ],
       [ "Multi-Threading Consideration for Expression Evaluation Library", "dd/d60/libeval.html#dhcpEvalMTConsiderations", null ]
@@ -379,7 +365,198 @@ var index =
     [ "libkea-http - Kea HTTP Library", "d1/d2a/libhttp.html", [
       [ "Multi-Threading Consideration for HTTP Library", "d1/d2a/libhttp.html#httpMTConsiderations", null ]
     ] ],
+    [ "libkea-d2srv - Kea D2 Server Library", "d3/de9/libd2srv.html", [
+      [ "Multi-Threading Consideration for D2 Server Library", "d3/de9/libd2srv.html#d2srvMTConsiderations", null ]
+    ] ],
+    [ "libkea-kea_tcp - TCP Listener Library", "da/d5b/libtcp.html", [
+      [ "Introduction", "da/d5b/libtcp.html#libkea_tcpIntro", null ],
+      [ "Multi-Threading Consideration for TCP Library", "da/d5b/libtcp.html#tcpMTConsiderations", null ]
+    ] ],
+    [ "Kea GSS-TSIG Hooks Library", "d6/d1e/libddns_gss_tsig.html", [
+      [ "Overview", "d6/d1e/libddns_gss_tsig.html#gssTsigOverview", null ],
+      [ "References", "d6/d1e/libddns_gss_tsig.html#gssTsigReferences", null ],
+      [ "GSS-API", "d6/d1e/libddns_gss_tsig.html#gssTsigGssApi", null ],
+      [ "Commands", "d6/d1e/libddns_gss_tsig.html#gssTsigGssCommands", null ],
+      [ "Library Internals", "d6/d1e/libddns_gss_tsig.html#gssTsigInternals", [
+        [ "Framework", "d6/d1e/libddns_gss_tsig.html#autotoc_md2", null ],
+        [ "Callouts", "d6/d1e/libddns_gss_tsig.html#autotoc_md3", null ],
+        [ "The automatic key expiration and rekey process", "d6/d1e/libddns_gss_tsig.html#autotoc_md4", null ]
+      ] ],
+      [ "Choice of the C++11 chrono clock", "d6/d1e/libddns_gss_tsig.html#gssTsigCpp11ChronoClock", null ],
+      [ "Multi-Threading Compatibility", "d6/d1e/libddns_gss_tsig.html#gssTsigMTCompatibility", null ]
+    ] ],
+    [ "Kea Bootp Hooks Library", "d5/d92/libdhcp_bootp.html", [
+      [ "Introduction", "d5/d92/libdhcp_bootp.html#libdhcp_bootpIntro", null ],
+      [ "Now To Use libdhcp_bootp", "d5/d92/libdhcp_bootp.html#libdhcp_bootpUser", [
+        [ "Introduction", "d5/d92/libdhcp_bootp.html#autotoc_md5", null ],
+        [ "Configuring the DHCPv4 Module", "d5/d92/libdhcp_bootp.html#autotoc_md6", null ],
+        [ "Internal operation", "d5/d92/libdhcp_bootp.html#autotoc_md7", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "d5/d92/libdhcp_bootp.html#libdhcp_bootpMTCompatibility", null ]
+    ] ],
+    [ "Kea Class Commands Hooks Library", "d0/df6/libdhcp_class_cmds.html", [
+      [ "Overview", "d0/df6/libdhcp_class_cmds.html#class_cmds", [
+        [ "Introduction", "d0/df6/libdhcp_class_cmds.html#autotoc_md8", null ],
+        [ "Internal structure", "d0/df6/libdhcp_class_cmds.html#autotoc_md9", null ],
+        [ "Regenerating this documentation", "d0/df6/libdhcp_class_cmds.html#autotoc_md10", null ],
+        [ "Testing", "d0/df6/libdhcp_class_cmds.html#autotoc_md11", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "d0/df6/libdhcp_class_cmds.html#class_cmdsMTCompatibility", null ]
+    ] ],
+    [ "Kea DDNS Tuning Hooks Library", "de/d67/libdhcp_ddns_tuning.html", [
+      [ "Overview", "de/d67/libdhcp_ddns_tuning.html#cbDdnsTuningOverview", null ],
+      [ "Library Internals", "de/d67/libdhcp_ddns_tuning.html#cbDdnsTuningInternals", null ],
+      [ "Multi-Threading Compatibility", "de/d67/libdhcp_ddns_tuning.html#cbDdnsTuningMTCompatibility", null ]
+    ] ],
+    [ "Kea Flexible Identifier Hooks Library", "dc/d6e/libdhcp_flex_id.html", [
+      [ "How To Use Libdhcp_flex_id", "dc/d6e/libdhcp_flex_id.html#libdhcp_flex_idUser", [
+        [ "Introduction", "dc/d6e/libdhcp_flex_id.html#autotoc_md12", null ],
+        [ "Configuring the DHCP Modules", "dc/d6e/libdhcp_flex_id.html#autotoc_md13", null ],
+        [ "Internal operation", "dc/d6e/libdhcp_flex_id.html#autotoc_md14", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "dc/d6e/libdhcp_flex_id.html#libdhcp_flex_idMTCompatibility", null ]
+    ] ],
+    [ "Kea Flexible Option Hooks Library", "d5/d27/libdhcp_flex_option.html", [
+      [ "Introduction", "d5/d27/libdhcp_flex_option.html#libdhcp_flex_optionIntro", null ],
+      [ "Now To Use libdhcp_flex_option", "d5/d27/libdhcp_flex_option.html#libdhcp_flex_optionUser", [
+        [ "Introduction", "d5/d27/libdhcp_flex_option.html#autotoc_md15", null ],
+        [ "Configuring the DHCP Modules", "d5/d27/libdhcp_flex_option.html#autotoc_md16", null ],
+        [ "Internal operation", "d5/d27/libdhcp_flex_option.html#autotoc_md17", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "d5/d27/libdhcp_flex_option.html#libdhcp_flex_optionMTCompatibility", null ]
+    ] ],
+    [ "Kea High Availability Hooks Library", "d3/d96/libdhcp_ha.html", [
+      [ "Overview", "d3/d96/libdhcp_ha.html#haOverview", null ],
+      [ "Why Hook Library?", "d3/d96/libdhcp_ha.html#haWhyHookLibrary", null ],
+      [ "Notable Differences to ISC DHCP", "d3/d96/libdhcp_ha.html#haNotableDifferences", null ],
+      [ "Asynchronous Communication with Boost Asio", "d3/d96/libdhcp_ha.html#haAyncCommunication", null ],
+      [ "Client Classification in Load Balancing", "d3/d96/libdhcp_ha.html#haClientClassification", null ],
+      [ "HA Hooks Library Code Structure", "d3/d96/libdhcp_ha.html#haCodeStructure", [
+        [ "HA Service Class", "d3/d96/libdhcp_ha.html#haService", null ],
+        [ "HA Implementation Class", "d3/d96/libdhcp_ha.html#haImplementation", null ],
+        [ "Query Filter Class", "d3/d96/libdhcp_ha.html#haQueryFilter", null ],
+        [ "Communication State Class", "d3/d96/libdhcp_ha.html#haCommunicationState", null ],
+        [ "Command Creator Class", "d3/d96/libdhcp_ha.html#haCommandCreator", null ]
+      ] ],
+      [ "Future HA Hooks Library Improvement Ideas", "d3/d96/libdhcp_ha.html#haShortcomings", [
+        [ "Controlling State Machine", "d3/d96/libdhcp_ha.html#haStateMachineControl", null ],
+        [ "DNS Updates are not Coordinated", "d3/d96/libdhcp_ha.html#haNameUpdates", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "d3/d96/libdhcp_ha.html#haMTCompatibility", null ]
+    ] ],
+    [ "Kea Host Cache Hooks Library", "db/ddf/libdhcp_host_cache.html", [
+      [ "Overview", "db/ddf/libdhcp_host_cache.html#host_cache_library_overview", [
+        [ "Introduction", "db/ddf/libdhcp_host_cache.html#autotoc_md29", null ],
+        [ "Interface", "db/ddf/libdhcp_host_cache.html#autotoc_md30", null ],
+        [ "Callouts", "db/ddf/libdhcp_host_cache.html#autotoc_md31", null ],
+        [ "Internal structure", "db/ddf/libdhcp_host_cache.html#autotoc_md32", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "db/ddf/libdhcp_host_cache.html#host_cacheMTCompatibility", null ]
+    ] ],
+    [ "Kea Host Commands Hooks Library", "d5/d48/libdhcp_host_cmds.html", [
+      [ "Overview", "d5/d48/libdhcp_host_cmds.html#host_cmds", [
+        [ "Introduction", "d5/d48/libdhcp_host_cmds.html#autotoc_md33", null ],
+        [ "Applying reservation modifications", "d5/d48/libdhcp_host_cmds.html#autotoc_md34", null ],
+        [ "Internal structure", "d5/d48/libdhcp_host_cmds.html#autotoc_md35", null ],
+        [ "Regenerating this documentation", "d5/d48/libdhcp_host_cmds.html#autotoc_md36", null ],
+        [ "Testing", "d5/d48/libdhcp_host_cmds.html#autotoc_md37", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "d5/d48/libdhcp_host_cmds.html#host_cmdsMTCompatibility", null ]
+    ] ],
+    [ "Kea Lease Commands Hooks Library", "d9/dda/libdhcp_lease_cmds.html", [
+      [ "Introduction", "d9/dda/libdhcp_lease_cmds.html#libdhcp_lease_cmdsIntro", null ],
+      [ "Lease Commands Overview", "d9/dda/libdhcp_lease_cmds.html#lease_cmds", null ],
+      [ "Lease Commands Code Overview", "d9/dda/libdhcp_lease_cmds.html#lease_cmdsCode", null ],
+      [ "Lease Commands Design choices", "d9/dda/libdhcp_lease_cmds.html#lease_cmdsDesigns", null ],
+      [ "Multi-Threading Compatibility", "d9/dda/libdhcp_lease_cmds.html#lease_cmdsMTCompatibility", null ]
+    ] ],
+    [ "Kea Lease Query Hooks Library", "d7/ddb/libdhcp_lease_query.html", [
+      [ "Overview", "d7/ddb/libdhcp_lease_query.html#leaseQueryOverview", null ],
+      [ "Library Internals", "d7/ddb/libdhcp_lease_query.html#leaseQueryInternals", null ],
+      [ "Multi-Threading Compatibility", "d7/ddb/libdhcp_lease_query.html#leaseQueryMTCompatibility", null ]
+    ] ],
+    [ "Kea Legal Log Hooks Library", "d6/d2c/libdhcp_legal_log.html", [
+      [ "How To Use Libdhcp_legal_log", "d6/d2c/libdhcp_legal_log.html#libdhcp_legal_logUser", [
+        [ "Introduction", "d6/d2c/libdhcp_legal_log.html#autotoc_md18", null ],
+        [ "Log Files", "d6/d2c/libdhcp_legal_log.html#autotoc_md19", null ],
+        [ "DHCPv4 Log Detailed Structure", "d6/d2c/libdhcp_legal_log.html#autotoc_md20", null ],
+        [ "DHCPv6 Log Detailed Structure", "d6/d2c/libdhcp_legal_log.html#autotoc_md21", null ],
+        [ "Configuring the DHCP Modules", "d6/d2c/libdhcp_legal_log.html#autotoc_md22", null ]
+      ] ],
+      [ "Commented Design for Libdhcp_legal_log", "d6/d2c/libdhcp_legal_log.html#libdhcp_legal_logDesign", [
+        [ "Introduction", "d6/d2c/libdhcp_legal_log.html#autotoc_md23", null ],
+        [ "Framework", "d6/d2c/libdhcp_legal_log.html#autotoc_md24", null ],
+        [ "Callouts", "d6/d2c/libdhcp_legal_log.html#autotoc_md25", null ],
+        [ "Log Generation", "d6/d2c/libdhcp_legal_log.html#autotoc_md26", null ],
+        [ "Database", "d6/d2c/libdhcp_legal_log.html#autotoc_md27", null ],
+        [ "Syslog", "d6/d2c/libdhcp_legal_log.html#autotoc_md28", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "d6/d2c/libdhcp_legal_log.html#libdhcp_legal_logMTCompatibility", null ]
+    ] ],
+    [ "Kea Limits Hook Library", "d4/d69/libdhcp_limits.html", [
+      [ "Overview", "d4/d69/libdhcp_limits.html#limitsOverview", null ],
+      [ "Library Internals", "d4/d69/libdhcp_limits.html#limitsInternals", null ],
+      [ "Multi-Threading Compatibility", "d4/d69/libdhcp_limits.html#libdhcp_limitsMTCompatibility", null ]
+    ] ],
+    [ "Kea PerfMon Hooks Library", "d4/dcf/libdhcp_perfmon.html", [
+      [ "Introduction", "d4/dcf/libdhcp_perfmon.html#libdhcp_perfmonIntro", null ],
+      [ "PerfMon Overview", "d4/dcf/libdhcp_perfmon.html#perfmon", null ],
+      [ "Multi-Threading Compatibility", "d4/dcf/libdhcp_perfmon.html#perfmonMTCompatibility", null ]
+    ] ],
+    [ "Kea Ping Check Hooks Library", "d6/dd8/libdhcp_ping_check.html", [
+      [ "Overview", "d6/dd8/libdhcp_ping_check.html#cbPingCheckOverview", null ],
+      [ "Library Internals", "d6/dd8/libdhcp_ping_check.html#cbPingCheckInternals", null ],
+      [ "Multi-Threading Compatibility", "d6/dd8/libdhcp_ping_check.html#cbPingCheckMTCompatibility", null ]
+    ] ],
+    [ "Kea RADIUS Hook Library", "d3/d51/libdhcp_radius.html", [
+      [ "Overview", "d3/d51/libdhcp_radius.html#radius_library_overview", [
+        [ "Introduction", "d3/d51/libdhcp_radius.html#autotoc_md38", null ],
+        [ "Configuration", "d3/d51/libdhcp_radius.html#autotoc_md39", null ],
+        [ "RADIUS Attributes", "d3/d51/libdhcp_radius.html#autotoc_md40", null ],
+        [ "RADIUS Communication", "d3/d51/libdhcp_radius.html#autotoc_md41", null ],
+        [ "Shared network support", "d3/d51/libdhcp_radius.html#autotoc_md42", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "d3/d51/libdhcp_radius.html#radiusMTCompatibility", null ]
+    ] ],
+    [ "Kea Run Script Hooks Library", "de/d53/libdhcp_run_script.html", [
+      [ "Introduction", "de/d53/libdhcp_run_script.html#libdhcp_run_scriptIntro", null ],
+      [ "Now To Use libdhcp_run_script", "de/d53/libdhcp_run_script.html#libdhcp_run_scriptUser", [
+        [ "Introduction", "de/d53/libdhcp_run_script.html#autotoc_md43", null ],
+        [ "Configuring the DHCPv4 and DHCPv6 Modules", "de/d53/libdhcp_run_script.html#autotoc_md44", null ],
+        [ "Internal operation", "de/d53/libdhcp_run_script.html#autotoc_md45", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "de/d53/libdhcp_run_script.html#libdhcp_run_scriptMTCompatibility", null ]
+    ] ],
+    [ "Kea Stat Commands Hooks Library", "d1/d88/libdhcp_stat_cmds.html", [
+      [ "Introduction", "d1/d88/libdhcp_stat_cmds.html#libdhcp_stat_cmdsIntro", null ],
+      [ "Stat Commands Overview", "d1/d88/libdhcp_stat_cmds.html#stat_cmds", null ],
+      [ "Stat Commands Code Overview", "d1/d88/libdhcp_stat_cmds.html#stat_cmdsCode", [
+        [ "Lease Stat Commands Code Overview", "d1/d88/libdhcp_stat_cmds.html#stat_cmdsLeaseStatCode", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "d1/d88/libdhcp_stat_cmds.html#stat_cmdsMTCompatibility", null ]
+    ] ],
+    [ "Kea Subnet Commands Hooks Library", "d8/daa/libdhcp_subnet_cmds.html", [
+      [ "Overview", "d8/daa/libdhcp_subnet_cmds.html#subnet_cmds", [
+        [ "Introduction", "d8/daa/libdhcp_subnet_cmds.html#autotoc_md46", null ],
+        [ "Internal structure", "d8/daa/libdhcp_subnet_cmds.html#autotoc_md47", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "d8/daa/libdhcp_subnet_cmds.html#subnet_cmdsMTCompatibility", null ]
+    ] ],
+    [ "DHCP User Check Hooks Library", "d8/db2/libdhcp_user_chk.html", [
+      [ "user_chk: An Example Hooks Library", "d8/db2/libdhcp_user_chk.html#libdhcp_user_chkIntro", [
+        [ "Introduction", "d8/db2/libdhcp_user_chk.html#autotoc_md48", null ],
+        [ "User Registry Classes", "d8/db2/libdhcp_user_chk.html#autotoc_md49", null ],
+        [ "Callout Processing", "d8/db2/libdhcp_user_chk.html#autotoc_md50", null ],
+        [ "Using the library", "d8/db2/libdhcp_user_chk.html#autotoc_md51", [
+          [ "Creating the Registry File", "d8/db2/libdhcp_user_chk.html#autotoc_md52", null ],
+          [ "Configuring the DHCP Modules", "d8/db2/libdhcp_user_chk.html#autotoc_md53", null ]
+        ] ],
+        [ "User Check Outcome", "d8/db2/libdhcp_user_chk.html#autotoc_md54", null ]
+      ] ],
+      [ "Multi-Threading Compatibility", "d8/db2/libdhcp_user_chk.html#libdhcp_user_chkMTCompatibility", null ]
+    ] ],
     [ "Terminology", "d8/d09/terminology.html", null ],
+    [ "ChangeLog", "d5/d6f/changelog.html", null ],
     [ "Flex/Bison Parsers", "d0/d9b/parser.html", [
       [ "Parser background", "d0/d9b/parser.html#parserIntro", null ],
       [ "Flex/Bison Based Parser", "d0/d9b/parser.html#parserBisonIntro", null ],
@@ -400,7 +577,7 @@ var index =
         [ "Create a Message File", "d8/d33/logKeaLogging.html#logMessageFiles", null ],
         [ "Produce Source Files", "d8/d33/logKeaLogging.html#logSourceFiles", [
           [ "Message Compiler", "d8/d33/logKeaLogging.html#logMessageCompiler", null ],
-          [ "Include Message Compilation in Makefile", "d8/d33/logKeaLogging.html#logMakefile", null ]
+          [ "Include Message Compilation in meson.build", "d8/d33/logKeaLogging.html#logMeson", null ]
         ] ],
         [ "Using Logging Files in Program Development", "d8/d33/logKeaLogging.html#logUsage", [
           [ "Use in a C++ Program or Module", "d8/d33/logKeaLogging.html#logCppUsage", null ]
@@ -421,33 +598,8 @@ var index =
       [ "Logging Messages", "dd/d70/LoggingApi.html#LoggingApiLoggingMessages", null ],
       [ "Implementation Issues", "dd/d70/LoggingApi.html#LoggingApiImplementationIssues", null ]
     ] ],
-    [ "Socket session utility", "dc/d78/SocketSessionUtility.html", null ],
-    [ "Fuzzing Kea", "d9/d8b/fuzzer.html", [
-      [ "Introduction", "d9/d8b/fuzzer.html#fuzzIntro", null ],
-      [ "Types of Kea Fuzzing", "d9/d8b/fuzzer.html#fuzzTypes", [
-        [ "Fuzzing with Network Packets", "d9/d8b/fuzzer.html#fuzzTypeNetwork", null ],
-        [ "Fuzzing with Configuration Files", "d9/d8b/fuzzer.html#fuzzTypeConfig", null ]
-      ] ],
-      [ "Building Kea for Fuzzing", "d9/d8b/fuzzer.html#fuzzBuild", null ],
-      [ "Running the Fuzzer", "d9/d8b/fuzzer.html#fuzzRun", [
-        [ "Fuzzing with Network Packets", "d9/d8b/fuzzer.html#fuzzRunNetwork", null ],
-        [ "Fuzzing with Configuration Files", "d9/d8b/fuzzer.html#fuzzRunConfig", null ]
-      ] ],
-      [ "Internals", "d9/d8b/fuzzer.html#Fuzzing", [
-        [ "Fuzzing with Network Packets", "d9/d8b/fuzzer.html#fuzzInternalNetwork", null ],
-        [ "Fuzzing with Configuration Files", "d9/d8b/fuzzer.html#fuzzInternalConfig", null ],
-        [ "Changes Required for Multi-Threaded Kea", "d9/d8b/fuzzer.html#fuzzThreads", null ]
-      ] ],
-      [ "Notes", "d9/d8b/fuzzer.html#fuzzNotes", [
-        [ "Unit Test Failures", "d9/d8b/fuzzer.html#fuzzNotesUnitTests", null ]
-      ] ]
-    ] ],
-    [ "Kea Cross-Compiling Example", "de/d9a/crossCompile.html", [
-      [ "Cross-Compile Tool Chain", "de/d9a/crossCompile.html#toolChain", null ],
-      [ "How to get system and packages without a running Raspberry Pi", "de/d9a/crossCompile.html#noRaspberry", null ],
-      [ "Usual problems", "de/d9a/crossCompile.html#crossCompilePitfalls", null ],
-      [ "Usual Kea Dependencies", "de/d9a/crossCompile.html#raspbianDependencies", null ],
-      [ "Prepare Cross Compiling", "de/d9a/crossCompile.html#prepareCrossCompile", null ]
+    [ "Debugging Kea", "db/d4d/debug.html", [
+      [ "Enabling debug symbols", "db/d4d/debug.html#debugSymbols", null ]
     ] ],
     [ "Building Kea Documentation", "d2/d86/docs.html", [
       [ "Documenting new command", "d2/d86/docs.html#docsNewCommand", null ],
